..
      Copyright 2015 IBM
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

Welcome to networking-powervm's documentation!
==============================================

This project will provide an ML2 compatible agent for PowerVM Shared
Ethernet Adapter integration with OpenStack Neutron.

Documentation on Neutron can be found at the `Neutron Devref`_.

.. _`Neutron Devref`: http://docs.openstack.org/developer/neutron/devref

Networking-PowerVM Overview
===========================

Contents:

.. toctree::
    :maxdepth: 1

    readme

Networking-PowerVM Policies
===========================

Contents:

.. toctree::
   :maxdepth: 1

   policies/index

Networking-PowerVM Devref
=========================

Contents:

.. toctree::
   :maxdepth: 1

   devref/index
